# eric7.Plugins.VcsPlugins.vcsMercurial.LargefilesExtension.largefiles

Module implementing the largefiles extension interface.

### Global Attributes

None

### Classes

Largefiles | Class implementing the largefiles extension interface.

### Functions

None

## Largefiles

Class implementing the largefiles extension interface.

### Derived from

HgExtension

### Class Attributes

None

### Class Methods

None

### Methods

Largefiles | Constructor
hgAdd | Public method used to add a file to the Mercurial repository.
hgLfPull | Public method to pull missing large files into the local repository.
hgLfVerify | Public method to verify large files integrity.
hgLfconvert | Public slot to convert the repository format of the current project.

### Static Methods

None

#### Largefiles (Constructor)

Largefiles(vcs, ui=None)

Constructor

vcs (Hg)
  reference to the Mercurial vcs object
ui (QWidget)
  reference to a UI widget (defaults to None)

#### Largefiles.hgAdd

hgAdd(names, mode)

Public method used to add a file to the Mercurial repository.

names (str or list of str)
  file name(s) to be added
mode (str)
  add mode (one of 'normal' or 'large')

#### Largefiles.hgLfPull

hgLfPull(revisions=None)

Public method to pull missing large files into the local repository.

revisions (list of str)
  list of revisions to pull

#### Largefiles.hgLfVerify

hgLfVerify(mode)

Public method to verify large files integrity.

mode (str)
  verify mode (one of 'large', 'lfa' or 'lfc')

#### Largefiles.hgLfconvert

hgLfconvert(direction, projectFile)

Public slot to convert the repository format of the current project.

direction (str)
  direction of the conversion (one of 'largefiles' or 'normal')
projectFile (str)
  file name of the current project file

Raises ValueError:
  raised to indicate a bad value for the 'direction' parameter.

Up